==> qtjambi-qml-debuginfo-macos-6.5.8.jar: sources/QtJambiQml/QQmlApplicationEngine_shell.h <==
#ifndef QQMLAPPLICATIONENGINE_SHELL_H
#define QQMLAPPLICATIONENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlapplicationengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/QmlAPI>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsmanagedvalue.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlabstracturlinterceptor.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlincubator.h>
#include <QtQml/qqmlnetworkaccessmanagerfactory.h>
#include <QtJambi/RegistryAPI>


class QQmlApplicationEngine_shell : public QQmlApplicationEngine, public QtJambiShellInterface
{
public:
    QQmlApplicationEngine_shell(QAnyStringView uri0, QAnyStringView typeName1, QObject* parent2 = nullptr);
    QQmlApplicationEngine_shell(QObject* parent0 = nullptr);
    QQmlApplicationEngine_shell(const QString& filePath0, QObject* parent1 = nullptr);
    QQmlApplicationEngine_shell(const QUrl& url0, QObject* parent1 = nullptr);
    ~QQmlApplicationEngine_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQmlApplicationEngine_mshell;
    friend class QQmlApplicationEngine_oshell;
};


class QQmlApplicationEngine_mshell : public QQmlApplicationEngine_shell
{
public:
    using QQmlApplicationEngine_shell::QQmlApplicationEngine_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQmlApplicationEngine_oshell : public QQmlApplicationEngine_mshell
{
public:
    using QQmlApplicationEngine_mshell::QQmlApplicationEngine_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlApplicationEngine_access : public QQmlApplicationEngine
{
};

#endif // QQMLAPPLICATIONENGINE_SHELL_H

==> qtjambi-qml-debuginfo-macos-6.6.0.jar: sources/QtJambiQml/QQmlApplicationEngine_shell.h <==
#ifndef QQMLAPPLICATIONENGINE_SHELL_H
#define QQMLAPPLICATIONENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlapplicationengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtJambi/QmlAPI>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsmanagedvalue.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlabstracturlinterceptor.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlincubator.h>
#include <QtQml/qqmlnetworkaccessmanagerfactory.h>
#include <QtJambi/RegistryAPI>


class QQmlApplicationEngine_shell : public QQmlApplicationEngine, public QtJambiShellInterface
{
public:
    QQmlApplicationEngine_shell(QAnyStringView uri0, QAnyStringView typeName1, QObject* parent2 = nullptr);
    QQmlApplicationEngine_shell(QObject* parent0 = nullptr);
    QQmlApplicationEngine_shell(const QString& filePath0, QObject* parent1 = nullptr);
    QQmlApplicationEngine_shell(const QUrl& url0, QObject* parent1 = nullptr);
    ~QQmlApplicationEngine_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlApplicationEngine_access : public QQmlApplicationEngine
{
};

#endif // QQMLAPPLICATIONENGINE_SHELL_H
